@@ -15,7 +15,8 @@
 from obs.ilog import LogConf
 from obs.client import ObsClient
 from obs.model import *
-
+from obs.model import ExtensionHeader, FetchStatus
+from obs.workflow import WorkflowClient
 
 __all__ = [
     'LogConf',
@@ -72,6 +73,10 @@ __all__ = [
     'DeleteObjectsRequest',
     'ListMultipartUploadsRequest',
     'GetObjectRequest',
-    'UploadFileHeader'
+    'UploadFileHeader',
+    'Payer',
+    'ExtensionHeader',
+    'FetchStatus',
+    'WorkflowClient'
 ]
 
