@@ -87,7 +87,7 @@ DEFAULT_TASK_NUM = 8
 DEFAULT_TASK_QUEUE_SIZE = 20000
 
 
-OBS_SDK_VERSION = '3.19.11'
+OBS_SDK_VERSION = '3.20.5'
 
 V2_META_HEADER_PREFIX = 'x-amz-meta-'
 V2_HEADER_PREFIX = 'x-amz-'
@@ -108,6 +108,13 @@ IPv4_REGEX = '^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$'
 V2_SIGNATURE = 'v2'
 OBS_SIGNATURE = 'obs'
 
+FETCH_POLICY_KEY = "v1/extension_policy"
+FETCH_JOB_KEY = "v1/async-fetch/jobs"
+
+WORKFLOW_TEMPLATES = 'workflowtemplates'
+WORKFLOWS = 'workflows'
+WORKFLOWEXECUTIONS = 'workflowexecutions'
+
 ALLOWED_RESOURCE_PARAMTER_NAMES = (
         'acl',
         'backtosource',
@@ -158,7 +165,18 @@ ALLOWED_RESOURCE_PARAMTER_NAMES = (
         'x-image-save-bucket',
         'x-image-save-object',
         'x-image-process',
-        'x-oss-process'
+        'x-oss-process',
+
+        # workflow api
+        'x-workflow-prefix',
+        'x-workflow-start',
+        'x-workflow-limit',
+        'x-workflow-template-name',
+        'x-workflow-graph-name',
+        'x-workflow-execution-state',
+        'x-workflow-execution-type',
+        'x-workflow-next-marker',
+        'triggerpolicy'
 )
 
 ALLOWED_REQUEST_HTTP_HEADER_METADATA_NAMES = (
@@ -212,7 +230,8 @@ ALLOWED_RESPONSE_HTTP_HEADER_METADATA_NAMES = (
         'access-control-allow-methods',
         'access-control-expose-headers',
         'connection',
-        'x-reserved-indicator'
+        'x-reserved-indicator',
+        'x-oef-request-id'
 )
 
 
