@@ -1,10 +1,22 @@
 #!/usr/bin/python
 # -*- coding:utf-8 -*-
+# Copyright 2019 Huawei Technologies Co.,Ltd.
+# Licensed under the Apache License, Version 2.0 (the "License"); you may not use
+# this file except in compliance with the License.  You may obtain a copy of the
+# License at
+
+# http://www.apache.org/licenses/LICENSE-2.0
+
+# Unless required by applicable law or agreed to in writing, software distributed
+# under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
+# CONDITIONS OF ANY KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations under the License.
 
 import re
 import base64
 import hashlib
 import os
+import json
 from obs import const
 from obs import progress
 
@@ -163,6 +175,7 @@ def get_readable_entity(readable, chunk_size=65536, notifier=None, auto_close=Tr
                 conn.send(hex_chunk if const.IS_PYTHON2 else hex_chunk.encode('UTF-8'))
                 conn.send('\r\n' if const.IS_PYTHON2 else '\r\n'.encode('UTF-8'))
                 conn.send(chunk)
+                conn.send('\r\n' if const.IS_PYTHON2 else '\r\n'.encode('UTF-8'))
         finally:
             if hasattr(readable, 'close') and callable(readable.close) and auto_close:
                 readable.close()
@@ -379,3 +392,20 @@ def verify_attr_type(value, allowedAttrType):
 
 def lazyCallback(*args, **kwargs):
     pass
+
+
+def jsonLoadsForPy2(json_text):
+    return _byteify(json.loads(json_text, object_hook=_byteify), ignore_dicts=True)
+
+
+def _byteify(data, ignore_dicts=False):
+    if isinstance(data, const.UNICODE):
+        return data.encode('utf-8')
+    if isinstance(data, list):
+        return [_byteify(item, ignore_dicts=True) for item in data]
+    if isinstance(data, dict) and not ignore_dicts:
+        return {
+            _byteify(key, ignore_dicts=True): _byteify(value, ignore_dicts=True)
+            for key, value in data.iteritems()
+        }
+    return data
